from pymongo.database import Database

from .collections.cboe import CBOEQueries
from .collections.spot import SpotQueries


class QueryManager:
    def __init__(self, db: Database, cboe_collection_name: str, spot_collection_name: str):
        self.db = db
        self.cboe_queries = CBOEQueries(db=db, collection_name=cboe_collection_name)
        self.spot_queries = SpotQueries(db=db, collection_name=spot_collection_name)


from pymongo.database import Database
from typing import TypedDict
import datetime as dt


class SpotDocument(TypedDict):
    current_price: float


class SpotQueries:
    def __init__(self, db: Database, collection_name: str):
        self.collection_name = collection_name
        self.collection = db["radar-spot"]

    def insert_many(self, document: SpotDocument):
        now = dt.datetime.now(dt.timezone.utc)
        row_date = dt.datetime(
            year = now.year,
            month = now.month,
            day = now.day,
            hour = now.hour,
            minute = now.minute,
            second = 0
        )
        document["row_date"] = row_date
        return self.collection.insert_one(document)